Learn R Programming

tinylabels (version 0.2.5)

as.character.tiny_labelled: Conversion of Labelled Vectors

Description

Functions to convert labelled vectors to other types, possibly keeping the variable label and the class attribute tiny_labelled.

Usage

# S3 method for tiny_labelled
as.character(x, keep_label = TRUE, ...)

# S3 method for tiny_labelled as.logical(x, keep_label = TRUE, ...)

# S3 method for tiny_labelled as.integer(x, keep_label = TRUE, ...)

# S3 method for tiny_labelled as.double(x, keep_label = TRUE, ...)

# S3 method for tiny_labelled as.complex(x, keep_label = TRUE, ...)

Arguments

x

Object to be coerced

keep_label

Logical indicating whether the variable labels and class tiny_labelled should be kept.

...

Further arguments passed to methods