Learn R Programming

tinylabels (version 0.2.5)

unlabel: Remove Labels from Objects

Description

Remove variable_labels from a labelled vector or from the columns of a data frame.

Usage

unlabel(x)

Value

Object as x but without variable labels and with class tiny_labelled removed.

Arguments

x

An R object.