powered by
Remove variable_labels from a labelled vector or from the columns of a data frame.
unlabel(x)
Object as x but without variable labels and with class tiny_labelled removed.
x
tiny_labelled
An R object.